
/*
    CVad Channel Occupancy Detection Library Project Code
    Copyright (C) 2007-2015 Charles Brain, G4GUO and Steve Hajducek, N2CKH

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "StdAfx.h"
#include "vad.h"
#define _USE_MATH_DEFINES
#include "math.h"
#include "memory.h"

void CVad::restart( void )
{
	m_active        = 1;
	m_sample_clk    = 0;
	reset_mags();
	m_max_difs      = 0;
}
//
// Called at start of dwell period
//
void CVad::Start( void )
{
	restart();
}
//
// Set the decision threshold
//
void CVad::SetThreshold( float threshold )
{
	m_difs_thresh = threshold;
}
void CVad::SetFftLength( int length )
{
	m_fft_length = length;
}
//
// Called at end of dwell period
//
int CVad::Stop( void )
{
	m_active = 0;
	return GetFinalDecision();
}
float CVad::GetLevel( void )
{
	return m_max_difs;
}
//
// Called everytime the ALE modem processes a bit
//
void CVad::Input( float *mags )
{
	if( m_active )
	{
		//
		// This works at 8K
		//
		update_mags( mags );

		m_sample_clk = ++m_sample_clk%ANAL_SIZE;

		if( m_sample_clk == 0 )
		{
			// Do some processing, every 160 samples (20ms)
			float difs = calc_differences( m_mags );
			if( difs > m_max_difs ) m_max_difs = difs;
			reset_mags();
		}
	}
}

CVad::CVad(void)
{
	restart();
	m_active = 0;
}

CVad::~CVad(void)
{
}
